"use client"
import { useEffect, useState } from "react";
import { Dialog } from "@headlessui/react";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { faBars, faTimes } from "@fortawesome/free-solid-svg-icons";
import { useInView } from "react-intersection-observer";
import Image from "next/image";
import Link from "next/link";
import { usePathname } from 'next/navigation';
import NavLink from "@components/NavLink";
import ButtonDropdown from "@components/ButtonDropdown";
import { mergeClassNames } from "@/helpers";
import { rfwAppUrl, universityAppUrl } from "@/helpers/routes";
import studentIcon from "../../../public/images/studentIcon.png"
import coachIcon from "../../../public/images/coachIcon.png"
import businessIcon from "../../../public/images/business-icon.png"
import blogIcon from "../../../public/images/blogIcon.png"
import metamorphosisIcon from "../../../public/images/metamorphosisIcon.png"
import resourceCenterIcon from "../../../public/images/resourceIcon.png"

const navigation = [
	{ name: "Home", href: "https://www.readyforwork.africa/" },
	// { name: "Blog", href: "/#" },

];


const topics = [
	{
		title: "Education ",
		description: "Frequently asked questions about education.",
		href: "/topics/education",
	},
	{
		title: "Business ",
		description: "Frequently asked questions about business.",
		href: "/topics/business",
	},
	{
		title: "Coaching ",
		description: "Frequently asked questions about coaching.",
		href: "/topics/coaching",
	},

];

const accounts = [
	{
		title: "employer",
		description: "",
		// href: "https://www.readyforwork.africa/business",
		// href: "/business",
		target:"_blank",
		href: rfwAppUrl("/business"),
		icon: businessIcon
	},
	{
		title: "coach",
		description: "",
		// href: "https://www.readyforwork.africa/coaching",
		target:"_blank",
		href: rfwAppUrl("/coaching"),
		// href: "/coaching",
		icon:coachIcon
	},
	{
		title: "student",
		description: "",
		target:"_blank",
		href: universityAppUrl("/auth/register"),
		// href: "https://www.university.readyforwork.africa/auth/waitlist",
		icon:studentIcon 
	},

];

const mediaItems =[
	{
		title:"Blog",
		href:"https://sfanonline.org/blog",
		icon:blogIcon
	},
	{
		title:"Metamorphosis",
		href:"https://www.sfanonline.org/metamorphosis",
		icon:metamorphosisIcon
	},
	{
		title:"Resource Center",
		href:"https://www.sfanonline.org/resource-center",
		icon:resourceCenterIcon
	}
]

export default function NavBar(): JSX.Element {
	const [mobileMenuOpen, setMobileMenuOpen] = useState(false);
	const { ref, inView } = useInView({
		threshold: 0,
	});

	const [currentPath, setCurrentPath] = useState("/");
	const pathname = usePathname();

	const handleCurrentPath = (path: string) => {
		setCurrentPath(path.length === 0 ? "/" : "/" + path.split("/")[1]);
	};

	useEffect(() => {
		handleCurrentPath(pathname);
	}, [pathname]);

	return (
		<>
			<div
				className={
					(!inView ? " bg-rfw-dark text-white" : "") +
					" sticky z-10 top-0 w-full py-6 px-6 lg:px-24 text-white"
				}
			>
				<header>
					<nav
						className="flex items-center justify-between"
						aria-label="Global"
					>
						<div className="flex lg:flex-1">
							<Link href="/" className="-m-1.5 p-1.5 flex items-center space-x-2">
								<span className="sr-only">
									ReadyforWork University
								</span>
								<Image width={114} height={50} src="/images/rfw-logo-dark.png" alt="RFW Logo" priority />
								<span className="capitalize text-rfw-other font-black">Help Center</span>
							</Link>
						</div>
						<div>
							<div className="flex lg:hidden">
								<button
									type="button"
									className="-m-2.5 inline-flex items-center justify-center rounded-md p-2.5 text-gray-700"
									onClick={() => setMobileMenuOpen(true)}
								>
									<span className="sr-only">Open main menu</span>
									<FontAwesomeIcon
										icon={faBars}
										className="h-6 w-6 text-white"
										aria-hidden="true"
									/>
								</button>
							</div>
							<div className="hidden lg:flex lg:gap-x-2 mr-20  font-semibold">
								{navigation.map((item) => (
									<NavLink
										key={item.name}
										href={item.href}
										className={mergeClassNames(
											currentPath === item.href || currentPath === item.href + "/" ? " active " : "",
											"navlink"
										)}
									>
										{item.name}
									</NavLink>
								))}

								<ButtonDropdown activeClassName={
									topics.filter((topic) => (
										topic.href.toString().includes(currentPath) && currentPath !== "/"
									)).length > 0 ? " active "
										: ""
								} title="Topics" menuItems={topics} />
								<ButtonDropdown activeClassName={
									topics.filter((topic) => (
										topic.href.toString().includes(currentPath) && currentPath !== "/"
									)).length > 0 ? " active "
										: ""
								} title="Media" menuItems={mediaItems} />

								<NavLink
									href={rfwAppUrl("/contact")}
									className="navlink">
									{"Contact us"}
								</NavLink>


								<ButtonDropdown
									activeClassName={"bg-rfw-summer"}
									titleClassName="text-rfw-dark"
									title="Register"
									menuItems={accounts} />


							</div>
						</div>
					</nav>
					{/* Start of Mobile NavBar */}
					<Dialog
						as="div"
						className="lg:hidden"
						open={mobileMenuOpen}
						onClose={setMobileMenuOpen}
					>
						<div className="fixed inset-0 z-50" />
						<Dialog.Panel className="fixed inset-y-0 right-0 z-50 left-0  overflow-y-auto bg-rfw-dark pb-20 px-6 py-6  sm:ring-1 sm:ring-gray-900/10">
							<div className="flex items-center justify-between">
								<Link href={"/"} className="-m-1.5 p-1.5">
									<span className="sr-only">
										{process.env.APP_TITLE}
									</span>
								</Link>
								<button
									type="button"
									className="-m-2.5 rounded-md p-2.5 text-gray-700"
									onClick={() => setMobileMenuOpen(false)}
								>
									<span className="sr-only">Close menu</span>
									<FontAwesomeIcon
										icon={faTimes}
										className="h-6 w-6 text-rfw-summer"
										aria-hidden="true"
									/>
								</button>
							</div>
							
							{/* Mobile */}
							<div className="mt-6 flow-root">
								<div className="-my-6 ">
									<div className="space-y-2 py-6 flex flex-col  font-semibold">
										{navigation.map((item, idx: number) => (
											<NavLink
												key={`mobile-nav-link-${idx}`}
												href={item.href}
												className={mergeClassNames(
													currentPath === item.href ? "active-mobile-navlink" : "",
													"inline-flex mobile-navlink"
												)}
											>
												{item.name}
											</NavLink>
										))}
									</div>

									<div className="relative z-10  mt-[-1.5em]">
										<ButtonDropdown activeClassName={
											topics.filter((topic) => (
												topic.href.toString().includes(currentPath) && currentPath !== "/"
											)).length > 0 ? " active "
												: ""
										} title="Topics" menuItems={topics} />
									</div>
									<div id="" className="bg-white w-4/5 ml-4 rounded-xl">
										{topics.map((menuItem,index) => (
											<div
												key={index}
												className=" p-2 rounded"
												title={menuItem.description}
											>
												<div>
													<Link
														href={menuItem.href}
														// target={menuItem.target}
														className={mergeClassNames(
															"block px-2   text-rfw-dark capitalize"
														)}
													>
														{menuItem.title}
													</Link>
												</div>
											</div>
										))}
									</div>
									
									<div className="py-3">
										<span className=" text-lg font-black text-white font-montserrat ml-5">Media</span>
									</div>
									<div id="" className="bg-white w-4/5 ml-4 rounded-xl p-2">
										{mediaItems.map((menuItem,index) => (
											<div
												key={menuItem.title}
												className=" p-2 rounded"
												title={menuItem.title}
											>
												<div className="flex items-center justify-start">
													<Image
														width={25}
														src={menuItem.icon}
														alt={menuItem.title}
													/>
													<Link
														href={menuItem.href}
														// target={menuItem.target}
														className={mergeClassNames(
															"block px-2   text-rfw-dark capitalize"
														)}
													>
														{menuItem.title}
													</Link>
												</div>
											</div>
										))}
									</div>
									
									<div className="relative mt-2">
										<NavLink
											href={rfwAppUrl("/contact")}

											className="inline-flex mobile-navlink">

											{"Contact us"}
										</NavLink>
									</div>

									<div className="relative">

										<ButtonDropdown
											// activeClassName={"bg-rfw-summer"}
											// titleClassName="text-rfw-dark"
											title="Account"
											menuItems={accounts} />

									</div>
									<div id="" className="bg-white w-4/5 ml-4 rounded-xl p-2">
										{accounts.map((menuItem) => (
											<div
												key={menuItem.title}
												className=" p-2 rounded"
												title={menuItem.description}
											>
												<div className="flex items-center justify-start">
													<Image
														width={25}
														src={menuItem.icon}
														alt={menuItem.title}
													/>
													<Link
														href={menuItem.href}
														target={menuItem.target}
														className={mergeClassNames(
															"block px-2   text-rfw-dark capitalize"
														)}
													>
														{menuItem.title}
													</Link>
												</div>
											</div>
										))}
									</div>
								</div>
							</div>
						</Dialog.Panel>
					</Dialog>
				</header>
			</div>
			<div
				style={{ height: "10vh" }}
				ref={ref}
				className="text-rfw-dark  absolute  top-0 bg-rfw-dark opacity-50"
			/>
		</>
	);
}
